## venra

[![Project Status: WIP – Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.](https://www.repostatus.org/badges/latest/wip.svg)](https://www.repostatus.org/#wip)
[![PyPI version](https://badge.fury.io/py/venra.svg)](https://badge.fury.io/py/venra)
![Tests](https://github.com/codycollier/venra/workflows/Tests/badge.svg)


### Install

```bash
$ pip install venra
```

### Usage


```python

import venra

print(venra.stars)
```
